#[non_exhaustive]pub struct ChannelChatNotificationV1 {
pub broadcaster_user_id: UserId,
pub user_id: UserId,
}Available on crate feature
eventsub only.Expand description
channel.chat.notification: an event that appears in chat occurs, such as someone subscribing to the channel or a subscription is gifted.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.broadcaster_user_id: UserIdUser ID of the channel to receive chat notification events for.
user_id: UserIdThe user ID to read chat as.
Implementations