#[non_exhaustive]pub struct ChannelPointsCustomRewardUpdateV1 {
pub broadcaster_user_id: UserId,
pub reward_id: Option<RewardId>,
}Available on crate feature
eventsub only.Expand description
channel.channel_points_custom_reward.update: a custom channel points reward has been updated for the specified channel.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.broadcaster_user_id: UserIdThe broadcaster user ID for the channel you want to receive channel points custom reward remove notifications for.
reward_id: Option<RewardId>Optional. Specify a reward id to only receive notifications for a specific reward.
Implementations
Sourceimpl ChannelPointsCustomRewardUpdateV1
impl ChannelPointsCustomRewardUpdateV1
Sourcepub fn builder() -> ChannelPointsCustomRewardUpdateV1Builder<((), ())>
pub fn builder() -> ChannelPointsCustomRewardUpdateV1Builder<((), ())>
Create a builder for building ChannelPointsCustomRewardUpdateV1.
On the builder, call .broadcaster_user_id(...), .reward_id(...)(optional) to set the values of the fields.
Finally, call .build() to create the instance of ChannelPointsCustomRewardUpdateV1.
Sourceimpl ChannelPointsCustomRewardUpdateV1
impl ChannelPointsCustomRewardUpdateV1
Sourcepub fn broadcaster_user_id(broadcaster_user_id: impl Into<UserId>) -> Self
pub fn broadcaster_user_id(broadcaster_user_id: impl Into<UserId>) -> Self
The broadcaster user ID for the channel you want to receive channel points custom reward remove notifications for.